@@ -4,12 +4,12 @@ from __future__ import annotations
 import atexit
 import functools
 import os
-from pathlib import Path
+import pathlib
 from tempfile import TemporaryDirectory
-from typing import Iterable, NamedTuple, cast
+from typing import Iterable, NamedTuple
 from urllib.parse import urljoin
 
-from packaging.requirements import Requirement
+import packaging.requirements
 from packaging.utils import BuildTag, canonicalize_name, parse_wheel_filename
 from packaging.version import parse as parse_version
 
@@ -29,20 +29,13 @@ from unearth.utils import split_auth_from_url
 
 
 class BestMatch(NamedTuple):
-    """The best match for a package.
-    This is a named tuple with the following attributes in order:
-
-    Attributes:
-        best (Package): The best candidate
-            for the package.
-        candidates (list[Package]): All candidates for the
-            package.
-        applicable (list[Package]): Candidates
-            that match the requirement.
-    """
+    """The best match for a package."""
 
+    #: The best matching package, or None if no match was found.
     best: Package | None
+    #: The applicable packages, excluding those with unmatching versions.
     applicable: list[Package]
+    #: All candidates found for the requirement.
     candidates: list[Package]
 
 
@@ -147,7 +140,9 @@ class PackageFinder:
     def _build_find_link(self, find_link: str) -> Link:
         if os.path.exists(find_link):
             return Link.from_path(os.path.abspath(find_link))
-        return Link(find_link)
+        elif "://" in find_link:
+            return Link(find_link)
+        raise ValueError(f"Invalid find link or non-existing path: {find_link}")
 
     def _evaluate_links(
         self, links: Iterable[Link], evaluator: Evaluator
@@ -157,7 +152,7 @@ class PackageFinder:
     def _evaluate_packages(
         self,
         packages: Iterable[Package],
-        requirement: Requirement,
+        requirement: packaging.requirements.Requirement,
         allow_prereleases: bool | None = None,
     ) -> Iterable[Package]:
         evaluator = functools.partial(
@@ -253,7 +248,7 @@ class PackageFinder:
 
     def _find_packages_from_requirement(
         self,
-        requirement: Requirement,
+        requirement: packaging.requirements.Requirement,
         allow_yanked: bool | None = None,
         hashes: dict[str, list[str]] | None = None,
     ) -> Iterable[Package]:
@@ -266,7 +261,7 @@ class PackageFinder:
 
     def find_matches(
         self,
-        requirement: Requirement | str,
+        requirement: packaging.requirements.Requirement | str,
         allow_yanked: bool | None = None,
         allow_prereleases: bool | None = None,
         hashes: dict[str, list[str]] | None = None,
@@ -274,7 +269,7 @@ class PackageFinder:
         """Find all packages matching the given requirement, best match first.
 
         Args:
-            requirement (Requirement|str): A packaging.requirements.Requirement
+            requirement: A packaging.requirements.Requirement
                 instance or a string to construct it.
             allow_yanked (bool|None): Whether to allow yanked candidates,
                 or None to infer from the specifier.
@@ -286,7 +281,7 @@ class PackageFinder:
             list[Package]: The packages list sorted by best match
         """
         if isinstance(requirement, str):
-            requirement = Requirement(requirement)
+            requirement = packaging.requirements.Requirement(requirement)
         return sorted(
             self._evaluate_packages(
                 self._find_packages_from_requirement(requirement, allow_yanked, hashes),
@@ -299,15 +294,15 @@ class PackageFinder:
 
     def find_best_match(
         self,
-        requirement: Requirement | str,
+        requirement: packaging.requirements.Requirement | str,
         allow_yanked: bool | None = None,
         allow_prereleases: bool | None = None,
-        hashes: dict[str, list[str]] = None,
+        hashes: dict[str, list[str]] | None = None,
     ) -> BestMatch:
         """Find the best match for the given requirement.
 
         Args:
-            requirement (Requirement|str): A packaging.requirements.Requirement
+            requirement: A packaging.requirements.Requirement
                 instance or a string to construct it.
             allow_yanked (bool|None): Whether to allow yanked candidates,
                 or None to infer from the specifier.
@@ -319,7 +314,7 @@ class PackageFinder:
             BestMatch: The best match
         """
         if isinstance(requirement, str):
-            requirement = Requirement(requirement)
+            requirement = packaging.requirements.Requirement(requirement)
         candidates = list(
             self._find_packages_from_requirement(requirement, allow_yanked, hashes)
         )
@@ -332,10 +327,10 @@ class PackageFinder:
     def download_and_unpack(
         self,
         link: Link,
-        location: str | Path,
-        download_dir: str | Path | None = None,
+        location: str | pathlib.Path,
+        download_dir: str | pathlib.Path | None = None,
         hashes: dict[str, list[str]] | None = None,
-    ) -> Path:
+    ) -> pathlib.Path:
         """Download and unpack the package at the given link.
 
         If the link is a remote link, it will be downloaded to the ``download_dir``.
@@ -347,24 +342,24 @@ class PackageFinder:
 
         Args:
             link (Link): The link to download
-            location (str|Path): The destination directory
-            download_dir (str|Path|None): The directory to download to, or None to use a
+            location: The destination directory
+            download_dir: The directory to download to, or None to use a
                 temporary directory created by unearth.
             hashes (dict[str, list[str]]|None): The optional hash dict for validation.
 
         Returns:
-            Path: The path to the installable file or directory.
+            The path to the installable file or directory.
         """
         # Strip the rev part for VCS links
-        if hashes is None and link.hash_name:
-            hashes = {link.hash_name: [cast(str, link.hash)]}
+        if hashes is None:
+            hashes = link.hash_option
         if download_dir is None:
             download_dir = TemporaryDirectory(prefix="unearth-download-").name
         file = unpack_link(
             self.session,
             link,
-            Path(download_dir),
-            Path(location),
+            pathlib.Path(download_dir),
+            pathlib.Path(location),
             hashes,
             verbosity=self.verbosity,
         )
